@@ -26,22 +26,24 @@
 #' @param plotHist (logical) additional histogram of original, imputed and resultant distribution (made using \code{\link{matrixNAneighbourImpute}} )
 #' @param xLab (character) custom x-axis label 
 #' @param tit (character) custom title
+#' @param imputMethod (character) choose the imputation method (may be 'mode2'(default), 'mode1', 'datQuant', 'modeAdopt' or 'informed', for details see \code{\link{matrixNAneighbourImpute}} )
 #' @param seedNo (integer) seed-value for normal random values
-#' @param multCorMeth (character) 
+#' @param multCorMeth (character) define which method(s) for correction of multipl testing should be run (for choice : 'BH','lfdr','BY','tValTab', choosing several is possible)
 #' @param nLoop (integer) number of runs of independent \code{NA}-imputation
 #' @param lfdrInclude (logical) depreciated, please used \code{multCorMeth} instead (include lfdr estimations, may cause warning message(s) concerning convergence if few too lines/proteins in dataset tested).
 #' @param ROTSn (integer) depreciated, please used \code{multCorMeth} instead (number of repeats by \code{ROTS}, if \code{NULL} \code{ROTS} will not be called)
 #' @param silent (logical) suppress messages
+#' @param debug (logical) additional messages fro debugging
 #' @param callFrom (character) allows easier tracking of messages produced
 #' @return limma-type S3 object of class 'MArrayLM' which can be accessed; multiple results of testing or multiple testing correction types may get included ('p.value','FDR','BY','lfdr' or 'ROTS.BH')
 #' @seealso \code{\link[wrMisc]{moderTest2grp}}, \code{\link[wrMisc]{pVal2lfdr}}, \code{eBayes} in Bioconductor package \href{https://bioconductor.org/packages/release/bioc/html/limma.html}{limma}, \code{\link[stats]{t.test}},\code{ROTS} of Bioconductor package \href{https://bioconductor.org/packages/release/bioc/html/ROTS.html}{ROTS}   
 #' @examples
 #' set.seed(2015); rand1 <- round(runif(600) +rnorm(600,1,2),3)
 #' dat1 <- matrix(rand1,ncol=6) + matrix(rep((1:100)/20,6),ncol=6)
-#' dat1[13:16,1:3] <- dat1[13:16,1:3] +2    # augment lines 13:16 
-#' dat1[19:20,1:3] <- dat1[19:20,1:3] +3    # augment lines 19:20
-#' dat1[15:18,4:6] <- dat1[15:18,4:6] +1.4  # augment lines 15:18 
-#' dat1[dat1 <1] <- NA                    # mimick some NAs for low abundance
+#' dat1[13:16,1:3] <- dat1[13:16,1:3] +2      # augment lines 13:16 
+#' dat1[19:20,1:3] <- dat1[19:20,1:3] +3      # augment lines 19:20
+#' dat1[15:18,4:6] <- dat1[15:18,4:6] +1.4    # augment lines 15:18 
+#' dat1[dat1 <1] <- NA                        # mimick some NAs for low abundance
 #' ## normalize data
 #' boxplot(dat1, main="data before normalization")
 #' dat1 <- wrMisc::normalizeThis(as.matrix(dat1), meth="median")
@@ -51,11 +53,13 @@
 #' PLtestR1 <- testRobustToNAimputation(dat=dat1, gr=grp1, retnNA=TRUE, nLoop=70)
 #' names(PLtestR1)
 #' @export
-testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0.15,0.5), avSdL=NULL, plotHist=FALSE, xLab=NULL, tit=NULL, seedNo=NULL,  multCorMeth=NULL, nLoop=100, lfdrInclude=NULL, ROTSn=NULL,silent=FALSE,callFrom=NULL){
+testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0.15,0.5), avSdL=NULL, plotHist=FALSE, xLab=NULL, tit=NULL, imputMethod="mode2", 
+  seedNo=NULL,  multCorMeth=NULL, nLoop=100, lfdrInclude=NULL, ROTSn=NULL, silent=FALSE, debug=FALSE, callFrom=NULL) {
   fxNa <- wrMisc::.composeCallName(callFrom, newNa="testRobustToNAimputation")
+  if(debug) silent <- FALSE
   if(is.list(dat)) { if(all(c("quant","annot") %in% names(dat))) {
     if(length(dim(dat$annot)) ==2 & length(annot) <1) annot <- dat$annot    # recover$annot if not given separately
-    dat <- dat$quant }}
+    dat <- dat$quant } else stop("Invalid 'dat' : does NOT contain both '$quant' and '$annot !")}
   if(length(dim(dat)) !=2) stop("'dat' must be matrix or data.frame with >1 columns")
   if(is.data.frame(dat)) dat <- as.matrix(dat)
   if(length(gr) != ncol(dat)) stop("Number of columns in 'dat' and number of (group-)elements in 'gr' do not match !")
@@ -76,7 +80,8 @@ testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0
   if("lfdr" %in% multCorMeth) { lfdrInclude <- TRUE
   } else if("lfdr" %in% names(multCorMeth)) { lfdrInclude <- try(as.logical(multCorMeth["lfdr"]), silent=TRUE)
       if("try-error" %in% class(lfdrInclude)) { lfdrInclude <- FALSE; multCorMeth <- multCorMeth[-which(names(multCorMeth)== "lfdr")] } }
-  
+  if(length(lfdrInclude) <1) lfdrInclude <- FALSE            # if for some reason whatsoever ...
+      
   ## main
   isNA <- is.na(dat)
   chNA <- any(isNA)
@@ -85,10 +90,17 @@ testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0
   gr <- as.factor(gr)
   callFro <- try(as.factor(gr)) 
   if(class(callFro) == "try-error") message("+++++\n",fxNa," MAJOR PROBLEM with argument 'gr' !!  (possibly not sufficient level-names ?) \n+++++")
+  
   ## 1st pass
-  datI <- matrixNAneighbourImpute(dat, gr, seedNo=seedNo, retnNA=retnNA ,avSdH=avSdH, plotHist=plotHist, xLab=xLab, tit=tit, silent=silent, callFrom=fxNa)
-  datFi <- combineMultFilterNAimput(dat=dat, imputed=datI, grp=gr, annDat=annot, abundThr=stats::quantile(dat,0.02,na.rm=TRUE), silent=silent, callFrom=fxNa)  # number of unique peptides unknown !
-  ## done combineMultFilterNAimput
+  if(debug) message(fxNa,"start 1st pass,  no of NA: ",sum(isNA))
+       #cat("tt1\n"); tt1 <<- list(dat=dat,gr=gr,imputMethod=imputMethod,seedNo=seedNo, retnNA=retnNA, avSdH=avSdH,ROTSn=ROTSn)
+  datI <- matrixNAneighbourImpute(dat, gr, imputMethod=imputMethod, retnNA=retnNA ,avSdH=avSdH, plotHist=plotHist, xLab=xLab, tit=tit, seedNo=seedNo, silent=silent, callFrom=fxNa)
+       #cat("tt2\n"); tt2 <<- list(dat=dat,gr=gr,imputMethod=imputMethod,seedNo=seedNo, retnNA=retnNA, avSdH=avSdH,datI=datI,ROTSn=ROTSn,annot=annot)
+       #  imputed=datI; grp=gr; annDat=annot; abundThr=stats::quantile(dat,0.02,na.rm=TRUE)
+  if(debug) message(fxNa,"start combineMultFilterNAimput ")
+  datFi <- combineMultFilterNAimput(dat=dat, imputed=datI, grp=gr, annDat=annot, abundThr=stats::quantile(if(is.list(dat)) dat$quant else dat, 0.02,na.rm=TRUE), silent=silent, callFrom=fxNa)  # number of unique peptides unknown !
+       #cat("tt2b\n"); tt2b <<- list(dat=dat,gr=gr,imputMethod=imputMethod,seedNo=seedNo, retnNA=retnNA, avSdH=avSdH,datI=datI,ROTSn=ROTSn,datFi=datFi)
+  if(debug) message(fxNa,"done combineMultFilterNAimput")          # done combineMultFilterNAimput
   ## prepare for testing
   if(lfdrInclude) {
     chLfdr <- try(find.package("fdrtool"), silent=TRUE)
@@ -96,10 +108,12 @@ testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0
       message(fxNa,"Package 'fdrtool' not found ! Please install first from CRAN for calculating lfdr-values. Omitting (defaut) 'lfdr' option from argument 'multCorMeth' ..")
       lfdrInclude <- FALSE } }
   pwComb <- wrMisc::triCoord(length(levels(gr)))
+  if(debug) message(fxNa,"start 1st moderTestXgrp()")
   out <- wrMisc::moderTestXgrp(datFi$data, grp=gr, limmaOutput=TRUE, addResults=multCorMeth, silent=silent, callFrom=fxNa)   # can't do question specific filtering w/o explicit loop
+#cat("tt2c\n");
   
   chFDR <- names(out) =="FDR"
-  if(any(chFDR)) names(out)[which(chFDR)] <- "BH"               # rename $FDR to $BH
+  if(any(chFDR)) names(out)[which(chFDR)] <- "BH"                 # rename $FDR to $BH
   rownames(pwComb) <- colnames(out$t) 
   ## need to add $ROTS.p
   if(length(ROTSn)==1) if(ROTSn >0 & !is.na(ROTSn)) {  
@@ -109,6 +123,7 @@ testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0
   } else ROTSn <- NULL
   if(length(ROTSn)==1) if(ROTSn >0) {
     ## this requires package ROTS
+    if(debug) message(fxNa,"start ROTS   n=",ROTSn)
     comp <- wrMisc::triCoord(length(levels(gr)))
     rownames(comp) <- paste(levels(gr)[comp[,1]], levels(gr)[comp[,2]],sep="-")
     tmRO <- matrix(nrow=nrow(datFi$data), ncol=nrow(comp))
@@ -120,9 +135,11 @@ testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0
     out$ROTS.BH <- apply(tmRO, 2, stats::p.adjust, method="BH") 
     if(lfdrInclude) out$ROTS.lfdr <- apply(tmRO, 2, wrMisc::pVal2lfdr) 
   } 
+#cat("tt2d\n");
   
   ## subsequent rounds of NA-imputation  
   if(chNA & nLoop >1) { 
+    if(debug) message(fxNa,"subsequent rounds of NA-imputation   nLoop=",nLoop)
     pValTab <- tValTab <- array(NA, dim=c(nrow(dat), nrow(pwComb), nLoop))
     datIm <- array(NA, dim=c(nrow(dat), ncol(dat), nLoop))
     datIm[,,1] <- datFi$data
@@ -133,8 +150,12 @@ testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0
       pVaRotsTab[,,1] <- out$ROTS.p }
     for(i in 2:nLoop) {
       ## the repeated NA-imputation & testing   
-      if(length(seedNo)==1) seedNo <- seedNo +i  
-      datX <- matrixNAneighbourImpute(dat, gr, seedNo=seedNo, retnNA=retnNA, avSdH=avSdH, NAneigLst=datI$NAneigLst, plotHist=FALSE, silent=TRUE, callFrom=fxNa)$data
+      if(length(seedNo)==1) seedNo <- seedNo +i 
+       #cat("tt3\n"); tt3 <<- list(dat=dat,gr=gr,seedNo=seedNo, retnNA=retnNA, avSdH=avSdH,datI=datI, pValTab=pValTab,datIm=datIm,ROTSn=ROTSn)
+      datX <- matrixNAneighbourImpute(dat, gr, imputMethod=imputMethod, seedNo=seedNo, retnNA=retnNA, avSdH=avSdH, NAneigLst=datI$NAneigLst, plotHist=FALSE, silent=TRUE, callFrom=fxNa)$data
+
+#cat("tt3b\n");
+    if(debug) message(fxNa,"passed matrixNAneighbourImpute()   in loop no ",i)
 
   #1st round# datI <- matrixNAneighbourImpute(dat, gr, seedNo=seedNo, retnNA=retnNA ,avSdH=avSdH, plotHist=plotHist, xLab=xLab, tit=tit, silent=silent, callFrom=fxNa)
   #1st round# datFi <- combineMultFilterNAimput(dat=dat, imputed=datI, grp=gr, annDat=annot, abundThr=stats::quantile(dat,0.02,na.rm=TRUE), silent=silent, callFrom=fxNa) 
@@ -147,6 +168,7 @@ testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0
         for(i in 1:nrow(comp)) tmRO[which(datFi$filt[,i]),i] <- ROTS::ROTS(datFi$data[which(datFi$filt[,i]),which(useCol[,i])], groups=as.numeric(as.factor(gr[which(useCol[,i])])), B=ROTSn)$pvalue   # ,K=500  
         pVaRotsTab[,,i] <- tmRO } }
     
+#cat("tt3c\n");
     ## propagate filtering results to p-values (disqualify to NA)
     if(any(!datFi$filt)) {
       fiAr <- rep(datFi$filt,nLoop)    
@@ -165,6 +187,7 @@ testRobustToNAimputation <- function(dat, gr, annot=NULL, retnNA=TRUE, avSdH=c(0
   } else out$datImp <- datFi$data
   out$annot <- annot
   out$filter <- datFi$filt
+#cat("tt3d\n");
 
   ## update dimnames of out$datImp
   dimnames(out$datImp) <- list(if(is.null(rownames(out$lods))) rownames(out$annot) else rownames(out$lods), colnames(dat))
